=========
Changelog
=========

0.01 (2024-03-15)
-----------------

* Initial release

0.4 (2024-05-10)
-----------------

* Name space internal ids with class name

* Enable cache deletion via delete method

1.1 (2024-05-17)
-----------------

* Add ruff lint and format

* Enable pre-commit hooks
